@@ -10,6 +10,7 @@ parseargs()
 {
    ARGC=0
    ARGV=()
+	debhelper=
    while [ -n "$1" ]; do
       if [ "-V" = "$1" ] || [ "--version" = "$1" ]; then
          echo "Javahelper Version $VERSION"
@@ -17,31 +18,46 @@ parseargs()
       elif [ "-h" = "$1" ] || [ "--help" = "$1" ]; then
          syntax
       elif [ "--with" = "$1" ]; then
+			debhelper=true
 			shift
       elif [ "-" = "${1:1:1}" ]; then
       # long opt
-         optn="`echo $1 | sed -n 's/^--\([^=]*\)\(=.*\)*$/\1/p'`"
-         if [ -z "$optn" ] || ! echo $ARGS | grep $optn >/dev/null; then
-            echo "Invalid option: $optn"
-            syntax
+         optn="`sed 's/^--\([^=]*\)\(=.*\)*$/\1/;s/-/_/g' <<< $1`"
+         if [ -z "$optn" ] || ! echo $ARGS | sed 's/-/_/g' | grep $optn >/dev/null; then
+				if [ -z "$debhelper" ]; then
+					echo "Invalid option: $optn"
+					syntax
+				fi
          fi
          optv="`echo $1 | sed -n 's/^[^=]*=\(.*\)$/\1/p'`"
          if [ -z "$optv" ]; then
             optv=true
          fi
-         export opt_$optn="$optv"
+			optname="opt_$optn"
+			if [ -n "${!optname}" ]; then
+				export opt_$optn="${!optname} $optv"
+			else
+				export opt_$optn="$optv"
+			fi
       elif [ "-" = "${1:0:1}" ]; then
       # short opt
          optn="${1:1:1}"
          if [ -z "$optn" ] || ! echo $ARGS | grep $optn >/dev/null; then
-            echo "Invalid option: $optn"
-            syntax
+				if [ -z "$debhelper" ]; then
+					echo "Invalid option: $optn"
+					syntax
+				fi
          fi
          optv="${1:2}"
          if [ -z "$optv" ]; then
             optv=true
          fi
-         export opt_$optn="$optv"
+			optname="opt_$optn"
+			if [ -n "${!optname}" ]; then
+				export opt_$optn="${!optname} $optv"
+			else
+				export opt_$optn="$optv"
+			fi
       else
       # not-opt arg
          ARGV[$ARGC]="$1"
@@ -67,7 +83,7 @@ findpackages()
       echo $opt_package
    elif [ -n "$opt_i" ] || [ -n "$opt_indep" ]; then
       egrep '^(Package|Architecture)' debian/control | grep -B1 'Architecture: all'|sed -n '/^Package:/s/^[^:]*: *//p'
-   elif [ -n "$opt_s" ] || [ -n "$opt_arch" ]; then
+   elif [ -n "$opt_a" ] || [ -n "$opt_arch" ]; then
       egrep '^(Package|Architecture)' debian/control | grep -v 'Architecture: all' | grep -B1 Architecture|sed -n '/^Package:/s/^[^:]*: *//p'
    else
       sed -n '/^Package:/s/^[^:]*: *//p' debian/control
@@ -82,10 +98,9 @@ firstpackage()
 getarg()
 {
    while [ -n "$1" ]; do
-      optn="opt_$1"
+      optn="`sed 's/-/_/g' <<< opt_$1`"
       if [ -n "${!optn}" ]; then
          echo ${!optn}
-         return
       fi
       shift
    done
